==> boostcrm-widget-1.0.2.tgz: package/es/store/reducers/behavior.reducer.js <==
import _extends from 'babel-runtime/helpers/extends';
import _get from 'lodash/get';
import _findIndex from 'lodash/findIndex';

var _behaviorReducer;

import { createReducer } from '../../commons/utils/store';
import * as actionTypes from '../actions/action-type';
import { startConversationRequest, checkMediaDeviceSuccess, updateMediaPermission, startCallRequest, startCallError, startCallSuccess, receiveUpdateCallStatus, selectDevices, stopCallRequest, receiveMessageFromAdmin, leaveInformationSuccess, saveUserInfoRequest, receiveICEServerResponse, updateHasTriggeredWelcomeMessage, toggleChatRequest, trackingTheTriggerEvent, toggleTheSupportWidgetRequest } from '../actions';
import { CALL_STATUS } from '../../components/phone-call/constants';
import webrtc from '../../components/phone-call/webrtc';
import { updateCallInfoRequest } from '../actions/update-call.action';
import { BUTTON_STARTS } from '../../commons/constants/websocket';


function isFacebookApp() {
  var ua = navigator.userAgent || navigator.vendor || window.opera;
  return ua.indexOf('FBAN') > -1 || ua.indexOf('FBAV') > -1;
}

var initialState = {
  showChat: false,
  showSupportWidget: false,
  isStartConversationFromAdmin: false,
  hasTriggeredWelcomeMessage: false,
  lastTimeTriggeredWelcomeMessage: undefined,
  lastTimeAcceptChattingWithBot: undefined,
  lastTimeAcceptLeavingOfflineMessage: undefined,
  lastTimeReceivingMessageFromAdmin: undefined,
  alreadySubmitUserInfo: false,
  alreadyStartConversation: false,
  callInfo: {
    selectedSpeakerId: undefined,
    selectedMicrophoneId: undefined,
    isShowCall: false,
    completeCheckingDevice: false,
    isAllowAccessMicrophone: false,
    isDeviceSupport: false,
    devices: [],
    missedDevices: [],
    userRejectsPermission: undefined
  },
  userInfo: {
    name: undefined,
    email: undefined,
    phone: undefined
  },
  soundOn: true,
  numberOfNewMessages: 0,
  triggerStartingPointTracking: []
};

var behaviorReducer = (_behaviorReducer = {}, _behaviorReducer[toggleTheSupportWidgetRequest] = function (state, _ref) {
  var payload = _ref.payload;

  var status = _get(state, 'callInfo.callData.status');
  var isCalling = status === CALL_STATUS.INITIATED || status === CALL_STATUS.IN_PROGRESS || status === CALL_STATUS.RECONNECTING;

  // Don't change if calling
  if (isCalling) {
    return state;
  }

  return _extends({}, state, {
    showSupportWidget: payload,
    showChat: payload === false ? false : state.showChat,
    callInfo: _extends({}, state.callInfo || {}, {
      isShowCall: payload === false ? false : _get(state, 'callInfo.isShowCall'),
      callData: undefined
    })
  });
}, _behaviorReducer[toggleChatRequest] = function (state) {
  return _extends({}, state, {
    showChat: !state.showChat
  });
}, _behaviorReducer[startConversationRequest] = function (state, _ref2) {
  var _ref2$payload = _ref2.payload,
      fromButton = _ref2$payload.fromButton,
      isWorkingDay = _ref2$payload.isWorkingDay;

  return _extends({}, state, {
    alreadyStartConversation: true,
    hasTriggeredWelcomeMessage: fromButton === BUTTON_STARTS.START_CONVERSATION && isWorkingDay ? true : state.hasTriggeredWelcomeMessage,
    lastTimeAcceptChattingWithBot: fromButton === BUTTON_STARTS.CHAT_WITH_BOT ? new Date() : state.lastTimeAcceptChattingWithBot,
    lastTimeAcceptLeavingOfflineMessage: fromButton === BUTTON_STARTS.LEAVE_MESSAGE ? new Date() : state.lastTimeAcceptLeavingOfflineMessage
  });
}, _behaviorReducer[updateHasTriggeredWelcomeMessage] = function (state) {
  return _extends({}, state, {
    hasTriggeredWelcomeMessage: true,
    lastTimeTriggeredWelcomeMessage: new Date()
  });
}, _behaviorReducer[saveUserInfoRequest] = function (state, _ref3) {
  var payload = _ref3.payload;

  return _extends({}, state, {
    userInfo: _extends({}, state.userInfo, {
      name: _get(payload, 'name'),
      email: _get(payload, 'email'),
      phone: _get(payload, 'phone')
    }),
    alreadySubmitUserInfo: true
  });
}, _behaviorReducer[trackingTheTriggerEvent] = function (state, _ref4) {
  var _ref4$payload = _ref4.payload,
      startingPointType = _ref4$payload.startingPointType,
      startingPointId = _ref4$payload.startingPointId;

  console.log('trackingTheTriggerEvent: ');
  var existOneIndex = _findIndex(state.triggerStartingPointTracking, function (event) {
    return event.startingPointId === startingPointId;
  });
  var triggerStartingPointTracking = state.triggerStartingPointTracking || [];
  if (existOneIndex >= 0) {
    triggerStartingPointTracking[existOneIndex] = _extends({}, triggerStartingPointTracking[existOneIndex], {
      lastTime: new Date()
    });
  } else {
    triggerStartingPointTracking.push({
      startingPointType: startingPointType,
      startingPointId: startingPointId,
      lastTime: new Date()
    });
  }

  var now = new Date();
  var oneDayInMilleseconds = 1000 * 60 * 60 * 24;
  return _extends({}, state, {
    triggerStartingPointTracking: triggerStartingPointTracking.filter(function (event) {
      return Math.abs(now - event.lastTime) < oneDayInMilleseconds;
    })
  });
}, _behaviorReducer[actionTypes.TOGGLE_CALL] = function (state) {
  // console.log("toggleCall");
  var isShowing = _get(state, 'callInfo.isShowCall');
  var status = _get(state, 'callInfo.callData.status');
  var isCalling = status === CALL_STATUS.INITIATED || status === CALL_STATUS.IN_PROGRESS || status === CALL_STATUS.RECONNECTING;

  if (isCalling) {
    return state;
  }

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      isShowCall: !isShowing,
      callData: undefined
    })
  });
}, _behaviorReducer[updateMediaPermission] = function (state, _ref5) {
  var payload = _ref5.payload;

  var isAllow = payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      isAllowAccessMicrophone: isAllow,
      userRejectsPermission: !isAllow
    })
  });
}, _behaviorReducer[checkMediaDeviceSuccess] = function (state, _ref6) {
  var payload = _ref6.payload;

  // console.log("payload", payload);
  var totalAudioInput = payload.totalAudioInput,
      totalAudioOutput = payload.totalAudioOutput,
      devices = payload.devices,
      isAllowAcessMedia = payload.isAllowAcessMedia;


  var getMissedDevices = function getMissedDevices() {
    var results = [];
    if (totalAudioInput === 0) {
      results.push('input');
    }

    if (totalAudioOutput === 0) {
      results.push('output');
    }
  };
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      devices: devices,
      isAllowAccessMicrophone: isAllowAcessMedia,
      isDeviceSupport: !/iphone|ipod|ipad|ucbrowser/.test(window.navigator.userAgent.toLowerCase()) && !isFacebookApp() && (totalAudioInput > 0 || totalAudioOutput > 0),
      missedDevices: getMissedDevices()
    })
  });
}, _behaviorReducer[startCallRequest] = function (state, _ref7) {
  var payload = _ref7.payload;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: {
        status: CALL_STATUS.CONNECTING,
        subscriberPeerConnectionInfo: _get(payload, 'subscriberPeerConnectionInfo')
      }
    })
  });
}, _behaviorReducer[startCallSuccess] = function (state, _ref8) {
  var payload = _ref8.payload;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: {
        status: CALL_STATUS.QUEUED,
        subscriberPeerConnectionInfo: _get(payload, 'subscriberPeerConnectionInfo')
      }
    })
  });
}, _behaviorReducer[startCallError] = function (state, _ref9) {
  var payload = _ref9.payload;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: {
        error: _get(payload, 'error'),
        status: CALL_STATUS.FAILED
      }
    })
  });
}, _behaviorReducer[receiveICEServerResponse] = function (state, _ref10) {
  var payload = _ref10.payload;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: _extends({}, state.callInfo.callData, {
        iceServers: payload
      })
    })
  });
}, _behaviorReducer[receiveUpdateCallStatus] = function (state, _ref11) {
  var payload = _ref11.payload;

  // console.log("receiveUpdateCallStatus: ", payload);
  var status = _get(payload, ['status']);
  if (status === CALL_STATUS.COMPLETED || status === CALL_STATUS.ADMIN_CANCELED || status === CALL_STATUS.BUSY || status === CALL_STATUS.NO_ANSWER) {
    // console.log("STOP CALL");
    webrtc.stopCall();
  }
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: payload
    })
  });
}, _behaviorReducer[updateCallInfoRequest] = function (state, _ref12) {
  var payload = _ref12.payload;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: _extends({}, state.callInfo.callData, payload)
    })
  });
}, _behaviorReducer[leaveInformationSuccess] = function (state, _ref13) {
  var payload = _ref13.payload;

  return _extends({}, state, {
    userInfo: _extends({}, state.userInfo, {
      name: _get(payload, 'name'),
      email: _get(payload, 'email'),
      phone: _get(payload, 'phone')
    }),
    alreadySubmitUserInfo: true
  });
}, _behaviorReducer[selectDevices] = function (state, _ref14) {
  var _ref14$payload = _ref14.payload,
      speakerId = _ref14$payload.speakerId,
      microphoneId = _ref14$payload.microphoneId;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      selectedSpeakerId: speakerId,
      selectedMicrophoneId: microphoneId
    })
  });
}, _behaviorReducer[stopCallRequest] = function (state, _ref15) {
  var payload = _ref15.payload;

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: _extends({}, state.callInfo.callData, {
        status: payload.status
      })
    })
  });
}, _behaviorReducer[receiveMessageFromAdmin] = function (state, _ref16) {
  var payload = _ref16.payload;

  return _extends({}, state, {
    isStartConversationFromAdmin: state.alreadyStartConversation === false,
    lastTimeReceivingMessageFromAdmin: new Date()
  });
}, _behaviorReducer[actionTypes.SOUND_SETTING] = function (state) {
  return _extends({}, state, {
    soundOn: !state.soundOn
  });
}, _behaviorReducer);

export default (function () {
  var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : initialState;
  var action = arguments[1];
  return createReducer(behaviorReducer, state, action);
});

==> boostcrm-widget-1.0.8.tgz: package/es/store/reducers/behavior.reducer.js <==
import _extends from "@babel/runtime/helpers/extends";
import _get from "lodash/get";
import _findIndex from "lodash/findIndex";

var _behaviorReducer;

import { createReducer } from '../../commons/utils/store';
import * as actionTypes from '../actions/action-type';
import { startConversationRequest, checkMediaDeviceSuccess, updateMediaPermission, startCallRequest, startCallError, startCallSuccess, receiveUpdateCallStatus, selectDevices, stopCallRequest, receiveMessageFromAdmin, leaveInformationSuccess, saveUserInfoRequest, receiveICEServerResponse, updateHasTriggeredWelcomeMessage, toggleChatRequest, trackingTheTriggerEvent, toggleTheSupportWidgetRequest } from '../actions';
import { CALL_STATUS } from '../../components/phone-call/constants';
import webrtc from '../../components/phone-call/webrtc';
import { updateCallInfoRequest } from '../actions/update-call.action';
import { BUTTON_STARTS } from '../../commons/constants/websocket';

function isFacebookApp() {
  var ua = navigator.userAgent || navigator.vendor || window.opera;
  return ua.indexOf('FBAN') > -1 || ua.indexOf('FBAV') > -1;
}

var initialState = {
  showChat: false,
  showSupportWidget: false,
  isStartConversationFromAdmin: false,
  hasTriggeredWelcomeMessage: false,
  lastTimeTriggeredWelcomeMessage: undefined,
  lastTimeAcceptChattingWithBot: undefined,
  lastTimeAcceptLeavingOfflineMessage: undefined,
  lastTimeReceivingMessageFromAdmin: undefined,
  alreadySubmitUserInfo: false,
  alreadyStartConversation: false,
  callInfo: {
    selectedSpeakerId: undefined,
    selectedMicrophoneId: undefined,
    isShowCall: false,
    completeCheckingDevice: false,
    isAllowAccessMicrophone: false,
    isDeviceSupport: false,
    devices: [],
    missedDevices: [],
    userRejectsPermission: undefined
  },
  userInfo: {
    name: undefined,
    email: undefined,
    phone: undefined
  },
  soundOn: true,
  numberOfNewMessages: 0,
  triggerStartingPointTracking: []
};
var behaviorReducer = (_behaviorReducer = {}, _behaviorReducer[toggleTheSupportWidgetRequest] = function (state, _ref) {
  var payload = _ref.payload;

  var status = _get(state, 'callInfo.callData.status');

  var isCalling = status === CALL_STATUS.INITIATED || status === CALL_STATUS.IN_PROGRESS || status === CALL_STATUS.RECONNECTING; // Don't change if calling

  if (isCalling) {
    return state;
  }

  return _extends({}, state, {
    showSupportWidget: payload,
    showChat: payload === false ? false : state.showChat,
    callInfo: _extends({}, state.callInfo || {}, {
      isShowCall: payload === false ? false : _get(state, 'callInfo.isShowCall'),
      callData: undefined
    })
  });
}, _behaviorReducer[toggleChatRequest] = function (state) {
  return _extends({}, state, {
    showChat: !state.showChat
  });
}, _behaviorReducer[startConversationRequest] = function (state, _ref2) {
  var _ref2$payload = _ref2.payload,
      fromButton = _ref2$payload.fromButton,
      isWorkingDay = _ref2$payload.isWorkingDay;
  return _extends({}, state, {
    alreadyStartConversation: true,
    hasTriggeredWelcomeMessage: fromButton === BUTTON_STARTS.START_CONVERSATION && isWorkingDay ? true : state.hasTriggeredWelcomeMessage,
    lastTimeAcceptChattingWithBot: fromButton === BUTTON_STARTS.CHAT_WITH_BOT ? new Date() : state.lastTimeAcceptChattingWithBot,
    lastTimeAcceptLeavingOfflineMessage: fromButton === BUTTON_STARTS.LEAVE_MESSAGE ? new Date() : state.lastTimeAcceptLeavingOfflineMessage
  });
}, _behaviorReducer[updateHasTriggeredWelcomeMessage] = function (state) {
  return _extends({}, state, {
    hasTriggeredWelcomeMessage: true,
    lastTimeTriggeredWelcomeMessage: new Date()
  });
}, _behaviorReducer[saveUserInfoRequest] = function (state, _ref3) {
  var payload = _ref3.payload;
  return _extends({}, state, {
    userInfo: _extends({}, state.userInfo, {
      name: _get(payload, 'name'),
      email: _get(payload, 'email'),
      phone: _get(payload, 'phone')
    }),
    alreadySubmitUserInfo: true
  });
}, _behaviorReducer[trackingTheTriggerEvent] = function (state, _ref4) {
  var _ref4$payload = _ref4.payload,
      startingPointType = _ref4$payload.startingPointType,
      startingPointId = _ref4$payload.startingPointId;
  console.log('trackingTheTriggerEvent: ');

  var existOneIndex = _findIndex(state.triggerStartingPointTracking, function (event) {
    return event.startingPointId === startingPointId;
  });

  var triggerStartingPointTracking = state.triggerStartingPointTracking || [];

  if (existOneIndex >= 0) {
    triggerStartingPointTracking[existOneIndex] = _extends({}, triggerStartingPointTracking[existOneIndex], {
      lastTime: new Date()
    });
  } else {
    triggerStartingPointTracking.push({
      startingPointType: startingPointType,
      startingPointId: startingPointId,
      lastTime: new Date()
    });
  }

  var now = new Date();
  var oneDayInMilleseconds = 1000 * 60 * 60 * 24;
  return _extends({}, state, {
    triggerStartingPointTracking: triggerStartingPointTracking.filter(function (event) {
      return Math.abs(now - event.lastTime) < oneDayInMilleseconds;
    })
  });
}, _behaviorReducer[actionTypes.TOGGLE_CALL] = function (state) {
  // console.log("toggleCall");
  var isShowing = _get(state, 'callInfo.isShowCall');

  var status = _get(state, 'callInfo.callData.status');

  var isCalling = status === CALL_STATUS.INITIATED || status === CALL_STATUS.IN_PROGRESS || status === CALL_STATUS.RECONNECTING;

  if (isCalling) {
    return state;
  }

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      isShowCall: !isShowing,
      callData: undefined
    })
  });
}, _behaviorReducer[updateMediaPermission] = function (state, _ref5) {
  var payload = _ref5.payload;
  var isAllow = payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      isAllowAccessMicrophone: isAllow,
      userRejectsPermission: !isAllow
    })
  });
}, _behaviorReducer[checkMediaDeviceSuccess] = function (state, _ref6) {
  var payload = _ref6.payload;
  // console.log("payload", payload);
  var totalAudioInput = payload.totalAudioInput,
      totalAudioOutput = payload.totalAudioOutput,
      devices = payload.devices,
      isAllowAcessMedia = payload.isAllowAcessMedia;

  var getMissedDevices = function getMissedDevices() {
    var results = [];

    if (totalAudioInput === 0) {
      results.push('input');
    }

    if (totalAudioOutput === 0) {
      results.push('output');
    }
  };

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      devices: devices,
      isAllowAccessMicrophone: isAllowAcessMedia,
      isDeviceSupport: !/iphone|ipod|ipad|ucbrowser/.test(window.navigator.userAgent.toLowerCase()) && !isFacebookApp() && (totalAudioInput > 0 || totalAudioOutput > 0),
      missedDevices: getMissedDevices()
    })
  });
}, _behaviorReducer[startCallRequest] = function (state, _ref7) {
  var payload = _ref7.payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: {
        status: CALL_STATUS.CONNECTING,
        subscriberPeerConnectionInfo: _get(payload, 'subscriberPeerConnectionInfo')
      }
    })
  });
}, _behaviorReducer[startCallSuccess] = function (state, _ref8) {
  var payload = _ref8.payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: {
        status: CALL_STATUS.QUEUED,
        subscriberPeerConnectionInfo: _get(payload, 'subscriberPeerConnectionInfo')
      }
    })
  });
}, _behaviorReducer[startCallError] = function (state, _ref9) {
  var payload = _ref9.payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: {
        error: _get(payload, 'error'),
        status: CALL_STATUS.FAILED
      }
    })
  });
}, _behaviorReducer[receiveICEServerResponse] = function (state, _ref10) {
  var payload = _ref10.payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: _extends({}, state.callInfo.callData, {
        iceServers: payload
      })
    })
  });
}, _behaviorReducer[receiveUpdateCallStatus] = function (state, _ref11) {
  var payload = _ref11.payload;

  // console.log("receiveUpdateCallStatus: ", payload);
  var status = _get(payload, ['status']);

  if (status === CALL_STATUS.COMPLETED || status === CALL_STATUS.ADMIN_CANCELED || status === CALL_STATUS.BUSY || status === CALL_STATUS.NO_ANSWER) {
    // console.log("STOP CALL");
    webrtc.stopCall();
  }

  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: payload
    })
  });
}, _behaviorReducer[updateCallInfoRequest] = function (state, _ref12) {
  var payload = _ref12.payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: _extends({}, state.callInfo.callData, payload)
    })
  });
}, _behaviorReducer[leaveInformationSuccess] = function (state, _ref13) {
  var payload = _ref13.payload;
  return _extends({}, state, {
    userInfo: _extends({}, state.userInfo, {
      name: _get(payload, 'name'),
      email: _get(payload, 'email'),
      phone: _get(payload, 'phone')
    }),
    alreadySubmitUserInfo: true
  });
}, _behaviorReducer[selectDevices] = function (state, _ref14) {
  var _ref14$payload = _ref14.payload,
      speakerId = _ref14$payload.speakerId,
      microphoneId = _ref14$payload.microphoneId;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      selectedSpeakerId: speakerId,
      selectedMicrophoneId: microphoneId
    })
  });
}, _behaviorReducer[stopCallRequest] = function (state, _ref15) {
  var payload = _ref15.payload;
  return _extends({}, state, {
    callInfo: _extends({}, state.callInfo, {
      callData: _extends({}, state.callInfo.callData, {
        status: payload.status
      })
    })
  });
}, _behaviorReducer[receiveMessageFromAdmin] = function (state, _ref16) {
  var payload = _ref16.payload;
  return _extends({}, state, {
    isStartConversationFromAdmin: state.alreadyStartConversation === false,
    lastTimeReceivingMessageFromAdmin: new Date()
  });
}, _behaviorReducer[actionTypes.SOUND_SETTING] = function (state) {
  return _extends({}, state, {
    soundOn: !state.soundOn
  });
}, _behaviorReducer);
export default (function (state, action) {
  if (state === void 0) {
    state = initialState;
  }

  return createReducer(behaviorReducer, state, action);
});
